# SCIentific Google Earth Engine (scigee)

Author: Dr. Songyan Zhu University of Edinburgh
Contact: Songyan.Zhu@ed.ac.uk
Website: https://sites.google.com/view/uflux

Python interface with Google Earth Engine, to play, filter, select, visualise, and retrieve GEE datasets.
Some code is from or at least inspired by the geemap (https://github.com/gee-community/geemap) and ipygee (https://github.com/fitoprincipe/ipygee/tree/master) modules.
